/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wamblee.wicket.page;

import java.util.logging.Level;
import java.util.logging.Logger;

import org.apache.wicket.markup.html.WebPage;
import org.apache.wicket.protocol.http.WebResponse;

/**
 * Logs page events.
 * 
 * @author Erik Brakkee
 */
public class LoggingPageBehavior implements PageBehavior {

    private static final Logger LOG = Logger
        .getLogger(LoggingPageBehavior.class.getName());

    private Level level;

    /**
     * Constructs the behavior.
     */
    public LoggingPageBehavior(Level aLevel) {
        level = aLevel;
    }

    @Override
    public void onBeforeRender(WebPage aPage) {
        LOG.log(level, "onbeforeRender: " + aPage);
    }

    @Override
    public void setHeaders(WebPage aPage, WebResponse aResponse) {
        LOG.log(level, "setHeaders: " + aPage + " " + aResponse);
    }

    @Override
    public void onAfterRender(WebPage aPage) {
        LOG.log(level, "onAfterRender: " + aPage);
    }

    @Override
    public void onDetach(WebPage aPage) {
        LOG.log(level, "onDetach: " + aPage);
    }

}
